@@ -261,16 +261,6 @@ def is_backtracking(expr):
     )
 
 
-def forward_type(expr):
-    """
-    :param expr:
-    :return:  Effective type of this Forward
-    """
-    while is_forward(expr.type):
-        expr = expr.tokens[0]
-    return expr.type
-
-
 def stack_depth():
     count = 0
     f = sys._getframe()
